Privex Pyrewall
================

[![Build Status](https://travis-ci.com/Privex/pyrewall.svg?branch=master)](https://travis-ci.com/Privex/pyrewall) 
[![Codecov](https://img.shields.io/codecov/c/github/Privex/pyrewall)](https://codecov.io/gh/Privex/pyrewall)  
[![PyPi Version](https://img.shields.io/pypi/v/pyrewall.svg)](https://pypi.org/project/pyrewall/)
![License Button](https://img.shields.io/pypi/l/pyrewall) 
![PyPI - Downloads](https://img.shields.io/pypi/dm/pyrewall)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyrewall) 
![GitHub last commit](https://img.shields.io/github/last-commit/Privex/pyrewall)

An iptables firewall management system in Python.

![Screenshot of REPL](https://cdn.privex.io/github/pyrewall/pyrewall_repl.png)

WARNING: Still under construction

```
+===================================================+
|                 © 2019 Privex Inc.                |
|               https://www.privex.io               |
+===================================================+
|                                                   |
|        PyreWall - Python iptables firewall tool   |
|        License: X11/MIT                           |
|                                                   |
|        Core Developer(s):                         |
|                                                   |
|          (+)  Chris (@someguy123) [Privex]        |
|                                                   |
+===================================================+

PyreWall - A Python tool / service for managing iptables firewalls with ease
Copyright (c) 2019    Privex Inc. ( https://www.privex.io )

```